@@ -4,21 +4,27 @@ print("\n===============\nOpen Data Test Failures:\n===============")
 
 # Test 1: Open Data
 query = """
-    SELECT name FROM `bigquery-public-data.usa_names.usa_1910_2013`
+WITH ranked_names AS (
+    SELECT name, SUM(number) as total FROM `bigquery-public-data.usa_names.usa_1910_2013`
     WHERE state = "TX"
+    GROUP BY name
+    ORDER BY total DESC
     LIMIT 5
+)
+SELECT name FROM ranked_names
 """
 
 myProject = pythonbq(
     key_path="./private/bq_key.json",
 )
 output = myProject.query(sql=query)
+
 if output != [
-    {"name": "Mary"},
-    {"name": "Roberta"},
-    {"name": "Marguerite"},
-    {"name": "Katie"},
-    {"name": "Eunice"},
+    {"name": "James"},
+    {"name": "John"},
+    {"name": "Michael"},
+    {"name": "Robert"},
+    {"name": "David"},
 ]:
     print("Open Data Test Failed!")
 
@@ -26,13 +32,14 @@ print("\n===============\nData Structure Test Failures:\n===============")
 output = myProject.query(sql=query, out_type="list")
 if output != [
     ["name"],
-    ["Mary"],
-    ["Roberta"],
-    ["Marguerite"],
-    ["Katie"],
-    ["Eunice"],
+    ["James"],
+    ["John"],
+    ["Michael"],
+    ["Robert"],
+    ["David"],
 ]:
     print("Data Structure (list) Test Failed!")
+
 output = myProject.query(sql=query, out_type="raw")
-if output != [["Mary"], ["Roberta"], ["Marguerite"], ["Katie"], ["Eunice"]]:
+if output != [["James"], ["John"], ["Michael"], ["Robert"], ["David"]]:
     print("Data Structure (raw) Test Failed!")
